@@ -7,7 +7,7 @@ def validate(value):
     """
     Validate HEX color format (e.g., #RRGGBB).
     """
-    pattern = r'^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{8})$'
+    pattern = r'^(#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{8}))|([A-Fa-f0-9]{6}|[A-Fa-f0-9]{8})$'
     if not re.match(pattern, value):
         raise ValidationError(
             _(f"{value} is not a valid color. Please enter a valid color code(#RRGGBB).")
